@@ -7,7 +7,7 @@ use Carp;
 use Woothee::Util qw/update_map update_category update_version update_os/;
 use Woothee::DataSet qw/dataset/;
 
-our $VERSION = "1.0.1";
+our $VERSION = "1.2.0";
 
 sub challenge_msie {
     my ($ua,$result) = @_;
@@ -36,6 +36,14 @@ sub challenge_safari_chrome { # and Opera(blink)
 
     my $version = Woothee::DataSet->const('VALUE_UNKNOWN');
 
+    if ($ua =~ m{Edge/([.0-9]+)}o) {
+        # MS Edge
+        $version = $1;
+        update_map($result, dataset("Edge"));
+        update_version($result, $version);
+        return 1;
+    }
+
     if ($ua =~ m{(?:Chrome|CrMo|CriOS)/([.0-9]+)}o) {
         # Opera (blink)
         if ($ua =~ m{OPR/([.0-9]+)}o) {
@@ -98,6 +106,29 @@ sub challenge_opera {
     return 1;
 }
 
+sub challenge_webview {
+    my ($ua,$result) = @_;
+
+
+    my $version = Woothee::DataSet->const('VALUE_UNKNOWN');
+
+    # iOS
+    if ($ua =~ m{iP(hone;|ad;|od) .*like Mac OS X}o) {
+        return 0 if index($ua, "Safari/") > -1;
+
+        if ($ua =~ m{Version/([.0-9]+)}o) {
+            $version = $1;
+        }
+
+        update_version($result, $version);
+        update_map($result, dataset("Webview"));
+        return 1;
+    }
+
+    return 0;
+}
+
+
 sub challenge_sleipnir {
     my ($ua,$result) = @_;
 
