@@ -7,7 +7,7 @@ use Carp;
 use Woothee::Util qw/update_map update_category update_version update_os/;
 use Woothee::DataSet qw/dataset/;
 
-our $VERSION = "1.0.1";
+our $VERSION = "1.2.0";
 
 sub challenge_google {
     my ($ua,$result) = @_;
@@ -108,6 +108,10 @@ sub challenge_crawlers {
         update_map($result, dataset("facebook"));
         return 1;
     }
+    elsif (index($ua, "Twitterbot/") > -1) {
+        update_map($result, dataset("twitter"));
+        return 1;
+    }
     elsif (index($ua, "ichiro") > -1) {
         if (index($ua, "http://help.goo.ne.jp/door/crawler.html") > -1 || index($ua, "compatible; ichiro/mobile goo;") > -1) {
             update_map($result, dataset("goo"));
