@@ -7,7 +7,7 @@ use Carp;
 use Woothee::Util qw/update_map update_category update_version update_os update_os_version/;
 use Woothee::DataSet qw/dataset/;
 
-our $VERSION = "1.0.1";
+our $VERSION = "1.2.0";
 
 sub challenge_windows {
     my ($ua, $result) = @_;
@@ -38,7 +38,8 @@ sub challenge_windows {
     }
 
     my $version = $1;
-    if ($version eq "NT 6.3") { $data = dataset("Win8.1"); }
+    if ($version eq "NT 10.0") { $data = dataset("Win10"); }
+    elsif ($version eq "NT 6.3") { $data = dataset("Win8.1"); }
     elsif ($version eq "NT 6.2") { $data = dataset("Win8"); }
     elsif ($version eq "NT 6.1") { $data = dataset("Win7"); }
     elsif ($version eq "NT 6.0") { $data = dataset("WinVista"); }
@@ -144,6 +145,11 @@ sub challenge_smartphone {
         $data = dataset("Android");
     } elsif (index($ua, "CFNetwork") > -1) {
         $data = dataset("iOS");
+    } elsif (index($ua, "BB10") > -1) {
+        if ($ua =~ m!BB10(?:.+)Version/([.0-9]+)!) {
+            $os_version = $1;
+        }
+        $data = dataset("BlackBerry10");
     } elsif (index($ua, "BlackBerry") > -1) {
         if ($ua =~ m!BlackBerry(?:\d+)/([.0-9]+) !) {
             $os_version = $1;
